@@ -19,4 +19,4 @@ ip = str(get_my_ip())
 
 # main('makemigrations data')
 # main('migrate data')
-main('runserver ' + ip + ':8000')
+main('runserver',  ip + ':8000')
